@@ -381,7 +381,7 @@ lpre' = map flip2 . context1l'
 
 -- | All outward-directed 'LEdge's in a 'Context'.
 out' :: Context a b -> [LEdge b] 
-out' c@(_,v,_,_) = map (\(l,w)->(w,v,l)) (context4l' c)
+out' c@(_,v,_,_) = map (\(l,w)->(v,w,l)) (context4l' c)
 
 -- | All inward-directed 'LEdge's in a 'Context'.
 inn' :: Context a b -> [LEdge b] 
